@@ -22,5 +22,5 @@ def cli(ctx):
 
 cli.add_command(init)
 
-if __name__ == '__main__':
+def main():
     cli(obj={})
